summaryrefslogtreecommitdiff
path: root/src/modlistviewactions.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/modlistviewactions.h')
-rw-r--r--src/modlistviewactions.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/modlistviewactions.h b/src/modlistviewactions.h
index 3c225fbc..069bb1e6 100644
--- a/src/modlistviewactions.h
+++ b/src/modlistviewactions.h
@@ -31,9 +31,10 @@ public:
PluginListView* pluginView,
QObject* nxmReceiver);
// install the mod from the given archive
//
- void installMod(const QString& archivePath = "") const;
+ void installMod(const QString& archivePath = "", const QModelIndex& index = QModelIndex()) const;
// create an empty mod/a separator before the given mod or at
// the end of the list if the index is invalid
@@ -31,9 +31,10 @@ public:
PluginListView* pluginView,
QObject* nxmReceiver);
- // install the mod from the given archive
+ // install the mod from the given archive before "above" the mod with
+ // the given index
//